@@ -105,7 +105,7 @@ abstract class AbstractAdapter extends BaseAdapter
      * setTableName() - set the table name to be used in the select query
      *
      * @param  string $tableName
-     * @return DbTable Provides a fluent interface
+     * @return self Provides a fluent interface
      */
     public function setTableName($tableName)
     {
@@ -117,7 +117,7 @@ abstract class AbstractAdapter extends BaseAdapter
      * setIdentityColumn() - set the column name to be used as the identity column
      *
      * @param  string $identityColumn
-     * @return DbTable Provides a fluent interface
+     * @return self Provides a fluent interface
      */
     public function setIdentityColumn($identityColumn)
     {
@@ -129,7 +129,7 @@ abstract class AbstractAdapter extends BaseAdapter
      * setCredentialColumn() - set the column name to be used as the credential column
      *
      * @param  string $credentialColumn
-     * @return DbTable Provides a fluent interface
+     * @return self Provides a fluent interface
      */
     public function setCredentialColumn($credentialColumn)
     {
@@ -143,7 +143,7 @@ abstract class AbstractAdapter extends BaseAdapter
      * false) parameters. Default is false.
      *
      * @param  int|bool $flag
-     * @return DbTable Provides a fluent interface
+     * @return self Provides a fluent interface
      */
     public function setAmbiguityIdentity($flag)
     {
@@ -324,13 +324,20 @@ abstract class AbstractAdapter extends BaseAdapter
             $resultIdentities = array();
             // iterate result, most cross platform way
             foreach ($result as $row) {
+                // ZF-6428 - account for db engines that by default return uppercase column names
+                if (isset($row['ZEND_AUTH_CREDENTIAL_MATCH'])) {
+                    $row['zend_auth_credential_match'] = $row['ZEND_AUTH_CREDENTIAL_MATCH'];
+                    unset($row['ZEND_AUTH_CREDENTIAL_MATCH']);
+                }
                 $resultIdentities[] = $row;
             }
         } catch (\Exception $e) {
             throw new Exception\RuntimeException(
                 'The supplied parameters to DbTable failed to '
-                    . 'produce a valid sql statement, please check table and column names '
-                    . 'for validity.', 0, $e
+                . 'produce a valid sql statement, please check table and column names '
+                . 'for validity.',
+                0,
+                $e
             );
         }
         return $resultIdentities;
