@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -18,29 +18,20 @@ class Digits extends AbstractFilter
      *
      * Returns the string $value, removing all but digit characters
      *
-     * If the value provided is non-scalar, the value will remain unfiltered
-     * and an E_USER_WARNING will be raised indicating it's unfilterable.
+     * If the value provided is not integer, float or string, the value will remain unfiltered
      *
      * @param  string $value
      * @return string|mixed
      */
     public function filter($value)
     {
-        if (null === $value) {
-            return null;
+        if (is_int($value)) {
+            return (string) $value;
         }
-
-        if (!is_scalar($value)) {
-            trigger_error(
-                sprintf(
-                    '%s expects parameter to be scalar, "%s" given; cannot filter',
-                    __METHOD__,
-                    (is_object($value) ? get_class($value) : gettype($value))
-                ),
-                E_USER_WARNING
-            );
+        if (! (is_float($value) || is_string($value))) {
             return $value;
         }
+        $value = (string) $value;
 
         if (!StringUtils::hasPcreUnicodeSupport()) {
             // POSIX named classes are not supported, use alternative 0-9 match
@@ -53,6 +44,6 @@ class Digits extends AbstractFilter
             $pattern = '/[\p{^N}]/';
         }
 
-        return preg_replace($pattern, '', (string) $value);
+        return preg_replace($pattern, '', $value);
     }
 }
