@@ -3,7 +3,7 @@
  * Zend Framework (http://framework.zend.com/)
  *
  * @link      http://github.com/zendframework/zf2 for the canonical source repository
- * @copyright Copyright (c) 2005-2013 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
  * @license   http://framework.zend.com/license/new-bsd New BSD License
  */
 
@@ -11,13 +11,13 @@ namespace Zend\Form;
 
 use Traversable;
 use Zend\Form\Element\Collection;
-use Zend\Form\Exception;
 use Zend\InputFilter\CollectionInputFilter;
 use Zend\InputFilter\InputFilter;
 use Zend\InputFilter\InputFilterAwareInterface;
 use Zend\InputFilter\InputFilterInterface;
 use Zend\InputFilter\InputFilterProviderInterface;
 use Zend\InputFilter\InputProviderInterface;
+use Zend\InputFilter\ReplaceableInputInterface;
 use Zend\Stdlib\ArrayUtils;
 use Zend\Stdlib\Hydrator\HydratorInterface;
 
@@ -108,6 +108,13 @@ class Form extends Fieldset implements FormInterface
      */
     protected $preferFormInputFilter = true;
 
+    /**
+     * Has preferFormInputFilter been set with setPreferFormInputFilter?
+     *
+     * @var bool
+     */
+    protected $hasSetPreferFormInputFilter = false;
+
     /**
      * Are the form elements/fieldsets wrapped by the form name ?
      *
@@ -139,6 +146,10 @@ class Form extends Fieldset implements FormInterface
             $this->setPreferFormInputFilter($options['prefer_form_input_filter']);
         }
 
+        if (isset($options['use_input_filter_defaults'])) {
+            $this->setUseInputFilterDefaults($options['use_input_filter_defaults']);
+        }
+
         return $this;
     }
 
@@ -623,12 +634,12 @@ class Form extends Fieldset implements FormInterface
                 }
 
                 $value = $values;
-            } else {
-                if (!isset($data[$key])) {
-                    $data[$key] = array();
-                }
-                $this->prepareValidationGroup($fieldset, $data[$key], $validationGroup[$key]);
             }
+
+            if (!isset($data[$key])) {
+                $data[$key] = array();
+            }
+            $this->prepareValidationGroup($fieldset, $data[$key], $validationGroup[$key]);
         }
     }
 
@@ -643,6 +654,11 @@ class Form extends Fieldset implements FormInterface
         $this->hasValidated                = false;
         $this->hasAddedInputFilterDefaults = false;
         $this->filter                      = $inputFilter;
+
+        if (false === $this->hasSetPreferFormInputFilter) {
+            $this->preferFormInputFilter = false;
+        }
+
         return $this;
     }
 
@@ -712,6 +728,7 @@ class Form extends Fieldset implements FormInterface
     public function setPreferFormInputFilter($preferFormInputFilter)
     {
         $this->preferFormInputFilter = (bool) $preferFormInputFilter;
+        $this->hasSetPreferFormInputFilter = true;
         return $this;
     }
 
@@ -743,7 +760,7 @@ class Form extends Fieldset implements FormInterface
             $elements = $fieldset->getElements();
         }
 
-        if (!$fieldset instanceof Collection || $inputFilter instanceof CollectionInputFilter) {
+        if (!$fieldset instanceof Collection || !$fieldset->getTargetElement() instanceof FieldsetInterface || $inputFilter instanceof CollectionInputFilter) {
             foreach ($elements as $element) {
                 $name = $element->getName();
 
@@ -756,13 +773,20 @@ class Form extends Fieldset implements FormInterface
                         continue;
                     }
                     // Create a new empty default input for this element
-                    $spec = array('name' => $name, 'required' => false);
+                    $spec  = array('name' => $name, 'required' => false);
+                    $input = $inputFactory->createInput($spec);
                 } else {
                     // Create an input based on the specification returned from the element
                     $spec  = $element->getInputSpecification();
+                    $input = $inputFactory->createInput($spec);
+
+                    if ($inputFilter->has($name) && $inputFilter instanceof ReplaceableInputInterface) {
+                        $input->merge($inputFilter->get($name));
+                        $inputFilter->replace($input, $name);
+                        continue;
+                    }
                 }
 
-                $input = $inputFactory->createInput($spec);
                 $inputFilter->add($input, $name);
             }
 
