@@ -10,8 +10,6 @@
 namespace Zend\Mvc;
 
 use Zend\EventManager\EventsCapableInterface;
-use Zend\Http\Request;
-use Zend\Http\Response;
 
 interface ApplicationInterface extends EventsCapableInterface
 {
@@ -39,7 +37,7 @@ interface ApplicationInterface extends EventsCapableInterface
     /**
      * Run the application
      *
-     * @return Response
+     * @return self
      */
     public function run();
 }
